// src/context/MonthsOfStore.tsx
import {
  monthsOf
} from "@leight/calendar";
import { createStoreContext } from "@leight/context-client";
import { DateTime } from "@leight/i18n";
import { jsx } from "react/jsx-runtime";
var MonthsOfStore = createStoreContext({
  state: ({ state }) => (set, get) => ({
    monthsOf(date) {
      set({
        months: monthsOf({ date })
      });
      return get().months;
    },
    today() {
      set({
        months: monthsOf({ date: DateTime.now() })
      });
      return get().months;
    },
    prevYear() {
      set(({ months: { date } }) => ({
        months: monthsOf({ date: date.minus({ year: 1 }) })
      }));
      return get().months;
    },
    nextYear() {
      set(({ months: { date } }) => ({
        months: monthsOf({ date: date.plus({ year: 1 }) })
      }));
      return get().months;
    },
    ...state
  }),
  name: "MonthsOfStore",
  hint: "Add MonthsOfProvider or CalendarProvider."
});
var MonthsOfProvider = ({ date, ...props }) => {
  return /* @__PURE__ */ jsx(
    MonthsOfStore.Provider,
    {
      state: {
        months: monthsOf({ date })
      },
      ...props
    }
  );
};

// src/context/WeeksOfStore.tsx
import {
  weeksOf
} from "@leight/calendar";
import { createStoreContext as createStoreContext2 } from "@leight/context-client";
import { DateTime as DateTime2 } from "@leight/i18n";
import { jsx as jsx2 } from "react/jsx-runtime";
var WeeksOfStore = createStoreContext2({
  state: ({ state }) => (set, get) => ({
    weeksOf(date) {
      set({
        weeks: weeksOf({ date })
      });
      return get().weeks;
    },
    today() {
      set({
        weeks: weeksOf({ date: DateTime2.now() })
      });
      return get().weeks;
    },
    prevMonth() {
      set(({ weeks: { date } }) => ({
        weeks: weeksOf({ date: date.minus({ month: 1 }) })
      }));
      return get().weeks;
    },
    nextMonth() {
      set(({ weeks: { date } }) => ({
        weeks: weeksOf({ date: date.plus({ month: 1 }) })
      }));
      return get().weeks;
    },
    prevYear() {
      set(({ weeks: { date } }) => ({
        weeks: weeksOf({ date: date.minus({ year: 1 }) })
      }));
      return get().weeks;
    },
    nextYear() {
      set(({ weeks: { date } }) => ({
        weeks: weeksOf({ date: date.plus({ year: 1 }) })
      }));
      return get().weeks;
    },
    ...state
  }),
  name: "WeeksOfStore",
  hint: "Add WeeksOfProvider or CalendarProvider."
});
var WeeksOfProvider = ({ date, ...props }) => {
  return /* @__PURE__ */ jsx2(
    WeeksOfStore.Provider,
    {
      state: {
        weeks: weeksOf({ date })
      },
      ...props
    }
  );
};

// src/context/YearsOfStore.tsx
import {
  yearsOf
} from "@leight/calendar";
import { createStoreContext as createStoreContext3 } from "@leight/context-client";
import { DateTime as DateTime3 } from "@leight/i18n";
import { jsx as jsx3 } from "react/jsx-runtime";
var YearsOfStore = createStoreContext3({
  state: ({ state }) => (set, get) => ({
    yearsOf(date) {
      set({
        years: yearsOf({ date })
      });
      return get().years;
    },
    today() {
      set({
        years: yearsOf({ date: DateTime3.now() })
      });
      return get().years;
    },
    prevYear() {
      set(({ years: { date } }) => ({
        years: yearsOf({ date: date.minus({ year: 1 }) })
      }));
      return get().years;
    },
    nextYear() {
      set(({ years: { date } }) => ({
        years: yearsOf({ date: date.plus({ year: 1 }) })
      }));
      return get().years;
    },
    prevYears() {
      set(({ years: { count, date } }) => ({
        years: yearsOf({ date: date.minus({ year: count }) })
      }));
      return get().years;
    },
    nextYears() {
      set(({ years: { count, date } }) => ({
        years: yearsOf({ date: date.plus({ year: count }) })
      }));
      return get().years;
    },
    ...state
  }),
  name: "YearsOfStore",
  hint: "Add YearsOfProvider or CalendarProvider."
});
var YearsOfProvider = ({ date, ...props }) => {
  return /* @__PURE__ */ jsx3(
    YearsOfStore.Provider,
    {
      state: {
        years: yearsOf({ date })
      },
      ...props
    }
  );
};

// src/context/index.tsx
import { jsx as jsx4 } from "react/jsx-runtime";
var CalendarProvider = ({ children, date }) => {
  return /* @__PURE__ */ jsx4(
    YearsOfProvider,
    {
      date,
      children: /* @__PURE__ */ jsx4(
        MonthsOfProvider,
        {
          date,
          children: /* @__PURE__ */ jsx4(
            WeeksOfProvider,
            {
              date,
              children
            }
          )
        }
      )
    }
  );
};

// src/inline/DateRageInline.tsx
import { DateInline } from "@leight/i18n-client";
import { Breadcrumbs } from "@mantine/core";
import { jsx as jsx5, jsxs } from "react/jsx-runtime";
var DateRageInline = ({
  start,
  end,
  startOptions = { day: "numeric", month: "numeric" },
  endOptions,
  ...props
}) => {
  return /* @__PURE__ */ jsxs(
    Breadcrumbs,
    {
      separator: "\u2192",
      className: "secondary",
      ...props,
      children: [
        /* @__PURE__ */ jsx5(
          DateInline,
          {
            date: start,
            options: startOptions
          }
        ),
        /* @__PURE__ */ jsx5(
          DateInline,
          {
            date: end,
            options: endOptions
          }
        )
      ]
    }
  );
};

// src/ui/Calendar.tsx
import { DateInline as DateInline5 } from "@leight/i18n-client";
import {
  ActionIcon as ActionIcon2,
  Box as Box2,
  Button as Button4,
  Overlay as Overlay2
} from "@mantine/core";
import {
  IconCalendarSearch,
  IconX as IconX2
} from "@tabler/icons-react";
import { useState as useState2 } from "react";

// src/ui/Months.tsx
import { DateTime as DateTime4 } from "@leight/i18n";
import { DateInline as DateInline2 } from "@leight/i18n-client";
import { classNames as classNames2 } from "@leight/utils-client";
import {
  Button,
  Grid as Grid2,
  Group,
  Text
} from "@mantine/core";
import {
  IconChevronLeft,
  IconChevronRight
} from "@tabler/icons-react";

// src/ui/CalendarShell.tsx
import {
  switchScheme
} from "@leight/mantine";
import {
  isCallable,
  withBool
} from "@leight/utils";
import {
  BlockStore,
  classNames
} from "@leight/utils-client";
import {
  Box,
  createStyles,
  Grid,
  LoadingOverlay
} from "@mantine/core";
import { jsx as jsx6, jsxs as jsxs2 } from "react/jsx-runtime";
var useStyles = createStyles((theme) => ({
  calendar: {
    userSelect: "none"
  },
  calendarGrid: {
    border: "1px solid",
    borderColor: switchScheme(
      theme,
      theme.colors.gray[6],
      theme.colors.gray[4]
    ),
    borderBottom: "none",
    borderRight: "none",
    "&:last-child": {
      border: "1px solid",
      borderColor: switchScheme(
        theme,
        theme.colors.gray[6],
        theme.colors.gray[4]
      ),
      borderRight: "none"
    }
  },
  controlsGrid: {
    "& > div:last-child": {
      borderRight: "1px solid",
      borderRightColor: switchScheme(
        theme,
        theme.colors.gray[6],
        theme.colors.gray[4]
      )
    }
  },
  controls: {
    display: "flex",
    flex: "1 1 auto",
    alignItems: "center"
  },
  controlsLeft: {},
  controlsMiddle: {
    justifyContent: "center"
  },
  controlsRight: {
    justifyContent: "end"
  },
  controlsPrefix: {},
  controlsSuffix: {},
  header: {
    backgroundColor: switchScheme(
      theme,
      theme.colors.gray[6],
      theme.colors.gray[0]
    ),
    fontWeight: "bold",
    height: "3em",
    display: "flex",
    flex: "1 1 auto",
    justifyContent: "center",
    alignItems: "center"
  },
  cell: {
    height: "6em",
    padding: "0",
    "&:hover": {
      backgroundColor: switchScheme(
        theme,
        theme.colors.gray[6],
        theme.colors.gray[0]
      )
    }
  },
  monthCell: {
    display: "flex",
    flex: "1 1 auto",
    justifyContent: "center",
    alignItems: "center"
  },
  yearCell: {
    display: "flex",
    flex: "1 1 auto",
    justifyContent: "center",
    alignItems: "center"
  },
  row: {
    "& > div": {
      borderRight: "1px solid",
      borderColor: switchScheme(
        theme,
        theme.colors.gray[6],
        theme.colors.gray[4]
      )
    }
  },
  currentMonth: {
    fontWeight: "bold",
    backgroundColor: switchScheme(
      theme,
      theme.colors.gray[6],
      theme.colors.gray[1]
    )
  },
  currentYear: {
    fontWeight: "bold",
    backgroundColor: switchScheme(
      theme,
      theme.colors.gray[6],
      theme.colors.gray[1]
    )
  },
  currentWeek: {},
  currentDay: {
    backgroundColor: switchScheme(
      theme,
      theme.colors.gray[6],
      theme.colors.gray[2]
    )
  },
  inRange: {
    fontWeight: "bold"
  },
  outOfRange: {
    backgroundColor: switchScheme(
      theme,
      theme.colors.gray[6],
      theme.colors.gray[0]
    )
  }
}));
var renderComponent = (component, props) => isCallable(component) ? component(props) : component;
var CalendarShell = ({
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  events,
  withControls = true,
  controlsTopLeft,
  controlsTopMiddle,
  controlsTopRight,
  controlsBottomLeft,
  controlsBottomMiddle,
  controlsBottomRight,
  children,
  ...props
}) => {
  const blockStore = BlockStore.useOptionalState();
  const { classes } = useStyles();
  const controlColumnCount = 18;
  const controlWidth = 7;
  const renderProps = {
    classes
  };
  return /* @__PURE__ */ jsxs2(
    Box,
    {
      className: classes.calendar,
      ...props,
      children: [
        /* @__PURE__ */ jsx6(LoadingOverlay, { visible: withBool(blockStore?.isBlock, false) }),
        withControls && /* @__PURE__ */ jsxs2(
          Grid,
          {
            columns: controlColumnCount,
            className: classNames(
              classes.calendarGrid,
              classes.controlsGrid,
              classes.controlsPrefix
            ),
            m: 0,
            children: [
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlWidth,
                  className: classNames(
                    classes.controls,
                    classes.controlsLeft
                  ),
                  children: renderComponent(controlsTopLeft, renderProps)
                }
              ),
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlColumnCount - controlWidth * 2,
                  className: classNames(
                    classes.controls,
                    classes.controlsMiddle
                  ),
                  children: renderComponent(controlsTopMiddle, renderProps)
                }
              ),
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlWidth,
                  className: classNames(
                    classes.controls,
                    classes.controlsRight
                  ),
                  children: renderComponent(controlsTopRight, renderProps)
                }
              )
            ]
          }
        ),
        renderComponent(children, renderProps),
        withControls && (controlsBottomLeft || controlsBottomMiddle || controlsBottomRight) && /* @__PURE__ */ jsxs2(
          Grid,
          {
            columns: controlColumnCount,
            className: classNames(
              classes.calendarGrid,
              classes.controlsGrid,
              classes.controlsSuffix
            ),
            m: 0,
            children: [
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlWidth,
                  className: classNames(
                    classes.controls,
                    classes.controlsLeft
                  ),
                  children: renderComponent(controlsBottomLeft, renderProps)
                }
              ),
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlColumnCount - controlWidth * 2,
                  className: classNames(
                    classes.controls,
                    classes.controlsMiddle
                  ),
                  children: renderComponent(controlsBottomMiddle, renderProps)
                }
              ),
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlWidth,
                  className: classNames(
                    classes.controls,
                    classes.controlsRight
                  ),
                  children: renderComponent(controlsBottomRight, renderProps)
                }
              )
            ]
          }
        )
      ]
    }
  );
};

// src/ui/Months.tsx
import { Fragment, jsx as jsx7, jsxs as jsxs3 } from "react/jsx-runtime";
var Months = ({
  children,
  onClick,
  ...props
}) => {
  const { months: { months, isCurrent, date }, today, prevYear, nextYear } = MonthsOfStore.useState();
  const columnCount = 4;
  const rowCount = months.length / columnCount;
  return /* @__PURE__ */ jsx7(
    CalendarShell,
    {
      controlsTopLeft: /* @__PURE__ */ jsx7(Group, { spacing: "sm", children: /* @__PURE__ */ jsx7(Button.Group, { children: /* @__PURE__ */ jsx7(
        Button,
        {
          size: "sm",
          variant: "subtle",
          onClick: () => prevYear(),
          leftIcon: /* @__PURE__ */ jsx7(IconChevronLeft, {}),
          children: /* @__PURE__ */ jsx7(
            DateInline2,
            {
              date: date.minus({ year: 1 }),
              options: { year: "numeric" }
            }
          )
        }
      ) }) }),
      controlsTopMiddle: /* @__PURE__ */ jsx7(Group, { spacing: "sm", children: /* @__PURE__ */ jsx7(
        Button,
        {
          variant: "subtle",
          onClick: () => today(),
          disabled: isCurrent,
          children: /* @__PURE__ */ jsx7(Text, { c: "dimmed", children: isCurrent ? /* @__PURE__ */ jsx7(DateInline2, { date: DateTime4.now(), options: { day: "numeric", month: "long", year: "numeric" } }) : /* @__PURE__ */ jsx7(DateInline2, { date, options: { year: "numeric" } }) })
        }
      ) }),
      controlsTopRight: /* @__PURE__ */ jsx7(Group, { spacing: "sm", children: /* @__PURE__ */ jsx7(Button.Group, { children: /* @__PURE__ */ jsx7(
        Button,
        {
          size: "sm",
          variant: "subtle",
          onClick: () => nextYear(),
          rightIcon: /* @__PURE__ */ jsx7(IconChevronRight, {}),
          children: /* @__PURE__ */ jsx7(
            DateInline2,
            {
              date: date.plus({ year: 1 }),
              options: { year: "numeric" }
            }
          )
        }
      ) }) }),
      ...props,
      children: ({ classes }) => /* @__PURE__ */ jsxs3(Fragment, { children: [
        Array.from({ length: rowCount }, (_, row) => /* @__PURE__ */ jsx7(
          Grid2,
          {
            columns: columnCount,
            className: classNames2(
              classes.calendarGrid,
              classes.row
            ),
            m: 0,
            children: Array.from({ length: columnCount }, (_2, column) => {
              const month = months[row * columnCount + column];
              if (!month) {
                return null;
              }
              return /* @__PURE__ */ jsx7(
                Grid2.Col,
                {
                  span: 1,
                  className: classNames2(
                    classes.cell,
                    classes.monthCell,
                    month.isCurrent ? classes.currentMonth : void 0
                  ),
                  style: onClick ? { cursor: "pointer" } : void 0,
                  onClick: () => onClick?.({ month }),
                  children: month.name
                },
                month.id
              );
            })
          },
          `month${row}`
        )),
        children
      ] })
    }
  );
};

// src/ui/Weeks.tsx
import { DateTime as DateTime5 } from "@leight/i18n";
import { DateInline as DateInline3 } from "@leight/i18n-client";
import { classNames as classNames3 } from "@leight/utils-client";
import {
  ActionIcon,
  Button as Button2,
  Grid as Grid3,
  Group as Group2,
  Overlay,
  Stack,
  Text as Text2
} from "@mantine/core";
import { useDisclosure } from "@mantine/hooks";
import {
  IconCalendarEvent,
  IconChevronLeft as IconChevronLeft2,
  IconChevronRight as IconChevronRight2,
  IconChevronsLeft,
  IconChevronsRight,
  IconX
} from "@tabler/icons-react";
import {
  useRef,
  useState
} from "react";
import { Fragment as Fragment2, jsx as jsx8, jsxs as jsxs4 } from "react/jsx-runtime";
var Weeks = ({
  onClick,
  onChange = () => null,
  events,
  renderDayInline,
  highlightToday = true,
  defaultWithWeekNo = false,
  weekCountSize = 2,
  columnSize = 3,
  children,
  ...props
}) => {
  const {
    nextMonth,
    prevMonth,
    prevYear,
    nextYear,
    today,
    weeks: {
      weeks,
      list,
      start,
      isCurrent
    }
  } = WeeksOfStore.useState();
  const source = events?.useSource();
  const $events = events && source?.entities.filter((event) => events.schema.safeParse(event)).map((event) => events.schema.parse(event)).reduce((prev, current) => {
    const stamp = current.date.toLocaleString({ day: "numeric", month: "numeric", year: "numeric" });
    return {
      ...prev,
      [stamp]: (prev[stamp] || []).concat(current)
    };
  }, {});
  const [isOverlay, { open: openOverlay, close: closeOverlay }] = useDisclosure(false);
  const overlay = useRef();
  const [withWeeks, setWithWeeks] = useState(defaultWithWeekNo);
  const withOverlay = (children2) => {
    overlay.current = children2;
    openOverlay();
  };
  const columnCount = list.length * columnSize + (withWeeks ? weekCountSize : 0);
  return /* @__PURE__ */ jsx8(
    CalendarShell,
    {
      controlsTopLeft: /* @__PURE__ */ jsx8(Group2, { spacing: "sm", children: /* @__PURE__ */ jsxs4(Button2.Group, { children: [
        /* @__PURE__ */ jsx8(
          Button2,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => onChange({ weeks: prevMonth() }),
            leftIcon: /* @__PURE__ */ jsx8(IconChevronLeft2, {}),
            children: /* @__PURE__ */ jsx8(
              DateInline3,
              {
                date: start.minus({ month: 1 }),
                options: { month: "long" }
              }
            )
          }
        ),
        /* @__PURE__ */ jsx8(
          Button2,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => onChange({ weeks: prevYear() }),
            leftIcon: /* @__PURE__ */ jsx8(IconChevronsLeft, {}),
            children: /* @__PURE__ */ jsx8(
              DateInline3,
              {
                date: start.minus({ year: 1 }),
                options: { year: "numeric" }
              }
            )
          }
        )
      ] }) }),
      controlsTopMiddle: /* @__PURE__ */ jsx8(Group2, { spacing: "sm", children: /* @__PURE__ */ jsx8(
        Button2,
        {
          variant: "subtle",
          onClick: () => onChange({ weeks: today() }),
          disabled: isCurrent,
          children: /* @__PURE__ */ jsx8(Text2, { c: "dimmed", children: isCurrent ? /* @__PURE__ */ jsx8(DateInline3, { date: DateTime5.now(), options: { day: "numeric", month: "long", year: "numeric" } }) : /* @__PURE__ */ jsx8(DateInline3, { date: start, options: { month: "long", year: "numeric" } }) })
        }
      ) }),
      controlsTopRight: /* @__PURE__ */ jsx8(Group2, { spacing: "sm", children: /* @__PURE__ */ jsxs4(Button2.Group, { children: [
        /* @__PURE__ */ jsx8(
          Button2,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => onChange({ weeks: nextYear() }),
            rightIcon: /* @__PURE__ */ jsx8(IconChevronsRight, {}),
            children: /* @__PURE__ */ jsx8(
              DateInline3,
              {
                date: start.plus({ year: 1 }),
                options: { year: "numeric" }
              }
            )
          }
        ),
        /* @__PURE__ */ jsx8(
          Button2,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => onChange({ weeks: nextMonth() }),
            rightIcon: /* @__PURE__ */ jsx8(IconChevronRight2, {}),
            children: /* @__PURE__ */ jsx8(
              DateInline3,
              {
                date: start.plus({ month: 1 }),
                options: { month: "long" }
              }
            )
          }
        )
      ] }) }),
      controlsBottomLeft: /* @__PURE__ */ jsx8(
        ActionIcon,
        {
          variant: "subtle",
          onClick: () => setWithWeeks((weeks2) => !weeks2),
          children: /* @__PURE__ */ jsx8(IconCalendarEvent, {})
        }
      ),
      ...props,
      children: ({ classes }) => /* @__PURE__ */ jsxs4(Fragment2, { children: [
        isOverlay && /* @__PURE__ */ jsxs4(Overlay, { color: "#FFF", opacity: 1, children: [
          /* @__PURE__ */ jsxs4(Group2, { position: "apart", children: [
            /* @__PURE__ */ jsx8("div", {}),
            /* @__PURE__ */ jsx8(
              ActionIcon,
              {
                variant: "subtle",
                onClick: () => closeOverlay(),
                children: /* @__PURE__ */ jsx8(IconX, {})
              }
            )
          ] }),
          overlay.current
        ] }),
        /* @__PURE__ */ jsxs4(
          Grid3,
          {
            columns: columnCount,
            className: classNames3(
              classes.calendarGrid,
              classes.row
            ),
            m: 0,
            children: [
              withWeeks && /* @__PURE__ */ jsx8(
                Grid3.Col,
                {
                  span: weekCountSize,
                  className: classes.header,
                  children: /* @__PURE__ */ jsx8(ActionIcon, { variant: "light", children: /* @__PURE__ */ jsx8(IconCalendarEvent, {}) })
                }
              ),
              list.map((day) => /* @__PURE__ */ jsx8(
                Grid3.Col,
                {
                  span: columnSize,
                  className: classes.header,
                  children: day
                },
                `day-${day}`
              ))
            ]
          }
        ),
        weeks.map(({ days, number, isCurrent: isCurrent2, id }) => /* @__PURE__ */ jsxs4(
          Grid3,
          {
            columns: columnCount,
            className: classNames3(
              classes.calendarGrid,
              classes.row,
              isCurrent2 ? classes.currentWeek : void 0
            ),
            m: 0,
            children: [
              withWeeks && /* @__PURE__ */ jsxs4(
                Grid3.Col,
                {
                  span: weekCountSize,
                  children: [
                    number,
                    "."
                  ]
                }
              ),
              days.map((day) => /* @__PURE__ */ jsx8(
                Grid3.Col,
                {
                  span: columnSize,
                  className: classNames3(
                    classes.cell,
                    day.isCurrent && highlightToday ? classes.currentDay : void 0,
                    day.isOutOfRange ? classes.outOfRange : classes.inRange
                  ),
                  style: onClick ? { cursor: "pointer" } : void 0,
                  onClick: () => {
                    withOverlay(/* @__PURE__ */ jsx8("h1", { children: day.id }));
                    onClick?.({ day });
                  },
                  children: /* @__PURE__ */ jsxs4(
                    Stack,
                    {
                      justify: "space-between",
                      style: { height: "100%", padding: "0 0.3em" },
                      children: [
                        /* @__PURE__ */ jsxs4(Group2, { position: "apart", children: [
                          /* @__PURE__ */ jsx8(Group2, { spacing: 0, children: /* @__PURE__ */ jsx8(ActionIcon, { size: "sm", children: /* @__PURE__ */ jsx8(IconCalendarEvent, {}) }) }),
                          day.day.day
                        ] }),
                        renderDayInline && events ? /* @__PURE__ */ jsx8("div", { children: renderDayInline({
                          schema: events.schema,
                          day,
                          events: $events?.[day.id] || []
                        }) }) : null
                      ]
                    }
                  )
                },
                day.id
              ))
            ]
          },
          id
        )),
        children
      ] })
    }
  );
};

// src/ui/Years.tsx
import { DateInline as DateInline4 } from "@leight/i18n-client";
import { classNames as classNames4 } from "@leight/utils-client";
import {
  Button as Button3,
  Grid as Grid4,
  Group as Group3,
  Text as Text3
} from "@mantine/core";
import {
  IconChevronLeft as IconChevronLeft3,
  IconChevronRight as IconChevronRight3,
  IconChevronsLeft as IconChevronsLeft2,
  IconChevronsRight as IconChevronsRight2
} from "@tabler/icons-react";
import { Fragment as Fragment3, jsx as jsx9, jsxs as jsxs5 } from "react/jsx-runtime";
var Years = ({
  children,
  onClick,
  ...props
}) => {
  const {
    years: {
      years,
      isCurrent,
      start,
      end,
      columns,
      rows,
      count
    },
    today,
    prevYear,
    nextYear,
    prevYears,
    nextYears
  } = YearsOfStore.useState();
  return /* @__PURE__ */ jsx9(
    CalendarShell,
    {
      controlsTopLeft: /* @__PURE__ */ jsx9(Group3, { spacing: "sm", children: /* @__PURE__ */ jsxs5(Button3.Group, { children: [
        /* @__PURE__ */ jsx9(
          Button3,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => prevYears(),
            leftIcon: /* @__PURE__ */ jsx9(IconChevronsLeft2, {}),
            children: /* @__PURE__ */ jsx9(
              DateInline4,
              {
                date: start.minus({ year: count }),
                options: { year: "numeric" }
              }
            )
          }
        ),
        /* @__PURE__ */ jsx9(
          Button3,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => prevYear(),
            leftIcon: /* @__PURE__ */ jsx9(IconChevronLeft3, {}),
            children: /* @__PURE__ */ jsx9(
              DateInline4,
              {
                date: start.minus({ year: 1 }),
                options: { year: "numeric" }
              }
            )
          }
        )
      ] }) }),
      controlsTopMiddle: /* @__PURE__ */ jsx9(Group3, { spacing: "sm", children: /* @__PURE__ */ jsx9(
        Button3,
        {
          variant: "subtle",
          onClick: () => today(),
          disabled: isCurrent,
          children: /* @__PURE__ */ jsx9(Text3, { c: "dimmed", children: /* @__PURE__ */ jsx9(
            DateRageInline,
            {
              start,
              end,
              startOptions: { year: "numeric" },
              endOptions: { year: "numeric" }
            }
          ) })
        }
      ) }),
      controlsTopRight: /* @__PURE__ */ jsx9(Group3, { spacing: "sm", children: /* @__PURE__ */ jsxs5(Button3.Group, { children: [
        /* @__PURE__ */ jsx9(
          Button3,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => nextYear(),
            rightIcon: /* @__PURE__ */ jsx9(IconChevronRight3, {}),
            children: /* @__PURE__ */ jsx9(
              DateInline4,
              {
                date: end.plus({ year: 1 }),
                options: { year: "numeric" }
              }
            )
          }
        ),
        /* @__PURE__ */ jsx9(
          Button3,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => nextYears(),
            leftIcon: /* @__PURE__ */ jsx9(IconChevronsRight2, {}),
            children: /* @__PURE__ */ jsx9(
              DateInline4,
              {
                date: end.plus({ year: count }),
                options: { year: "numeric" }
              }
            )
          }
        )
      ] }) }),
      ...props,
      children: ({ classes }) => /* @__PURE__ */ jsxs5(Fragment3, { children: [
        Array.from({ length: rows }, (_, row) => /* @__PURE__ */ jsx9(
          Grid4,
          {
            columns,
            className: classNames4(
              classes.calendarGrid,
              classes.row
            ),
            m: 0,
            children: Array.from({ length: columns }, (_2, column) => {
              const year = years[row * columns + column];
              if (!year) {
                return null;
              }
              return /* @__PURE__ */ jsx9(
                Grid4.Col,
                {
                  span: 1,
                  className: classNames4(
                    classes.cell,
                    classes.yearCell,
                    year.isCurrent ? classes.currentYear : void 0
                  ),
                  style: onClick ? { cursor: "pointer" } : void 0,
                  onClick: () => onClick?.({ year }),
                  children: year.name
                },
                year.id
              );
            })
          },
          `year${row}`
        )),
        children
      ] })
    }
  );
};

// src/ui/Calendar.tsx
import { jsx as jsx10, jsxs as jsxs6 } from "react/jsx-runtime";
var Calendar = ({
  onClick,
  withControls = true,
  ...props
}) => {
  const { weeksOf: weeksOf2, weeks } = WeeksOfStore.useState(({ weeksOf: weeksOf3, weeks: weeks2 }) => ({ weeksOf: weeksOf3, weeks: weeks2 }));
  const { monthsOf: monthsOf2 } = MonthsOfStore.useState(({ monthsOf: monthsOf3 }) => ({ monthsOf: monthsOf3 }));
  const { yearsOf: yearsOf2 } = YearsOfStore.useState(({ yearsOf: yearsOf3 }) => ({ yearsOf: yearsOf3 }));
  const [selectMonth, setSelectMonth] = useState2(false);
  const [selectYear, setSelectYear] = useState2(false);
  return /* @__PURE__ */ jsx10(Box2, { pos: "relative", children: /* @__PURE__ */ jsxs6(
    Weeks,
    {
      onClick,
      withControls,
      controlsBottomMiddle: /* @__PURE__ */ jsxs6(Button4.Group, { children: [
        /* @__PURE__ */ jsx10(
          Button4,
          {
            variant: "subtle",
            onClick: () => {
              setSelectMonth(true);
              monthsOf2(weeks.date);
            },
            leftIcon: /* @__PURE__ */ jsx10(IconCalendarSearch, {}),
            children: /* @__PURE__ */ jsx10(DateInline5, { date: weeks.date, options: { month: "long" } })
          }
        ),
        /* @__PURE__ */ jsx10(
          Button4,
          {
            variant: "subtle",
            onClick: () => {
              setSelectYear(true);
              yearsOf2(weeks.date);
            },
            leftIcon: /* @__PURE__ */ jsx10(IconCalendarSearch, {}),
            children: /* @__PURE__ */ jsx10(DateInline5, { date: weeks.date, options: { year: "numeric" } })
          }
        )
      ] }),
      ...props,
      children: [
        selectMonth && /* @__PURE__ */ jsx10(Overlay2, { color: "#FFF", opacity: 1, children: /* @__PURE__ */ jsx10(
          Months,
          {
            onClick: ({ month: { month } }) => {
              weeksOf2(month);
              setSelectMonth(false);
            },
            controlsBottomMiddle: /* @__PURE__ */ jsx10(
              ActionIcon2,
              {
                variant: "subtle",
                onClick: () => setSelectMonth(false),
                children: /* @__PURE__ */ jsx10(IconX2, {})
              }
            )
          }
        ) }),
        selectYear && /* @__PURE__ */ jsx10(Overlay2, { color: "#FFF", opacity: 1, children: /* @__PURE__ */ jsx10(
          Years,
          {
            onClick: ({ year: { year } }) => {
              weeksOf2(year);
              setSelectYear(false);
            },
            controlsBottomMiddle: /* @__PURE__ */ jsx10(
              ActionIcon2,
              {
                variant: "subtle",
                onClick: () => setSelectYear(false),
                children: /* @__PURE__ */ jsx10(IconX2, {})
              }
            )
          }
        ) })
      ]
    }
  ) });
};
export {
  Calendar,
  CalendarProvider,
  CalendarShell,
  DateRageInline,
  Months,
  MonthsOfProvider,
  MonthsOfStore,
  Weeks,
  WeeksOfProvider,
  WeeksOfStore,
  Years,
  YearsOfProvider,
  YearsOfStore
};
//# sourceMappingURL=index.js.map
