import { type ICalendarEventSchema } from "@leight/calendar";
import { type InferSelectors } from "@leight/mantine";
import { type ISourceSchema, type IUseSourceState } from "@leight/source";
import { Container } from "@mantine/core";
import { type ComponentProps, type ReactNode } from "react";
declare const useStyles: (params: void, options?: import("@mantine/core").UseStylesOptions<string> | undefined) => {
    classes: {
        calendar: string;
        calendarGrid: string;
        controlsGrid: string;
        controls: string;
        controlsLeft: string;
        controlsMiddle: string;
        controlsRight: string;
        controlsPrefix: string;
        controlsSuffix: string;
        header: string;
        cell: string;
        monthCell: string;
        yearCell: string;
        row: string;
        currentMonth: string;
        currentYear: string;
        currentWeek: string;
        currentDay: string;
        inRange: string;
        outOfRange: string;
    };
    cx: (...args: any) => string;
    theme: import("@mantine/core").MantineTheme;
};
export type ICalendarStyles = InferSelectors<typeof useStyles>;
export type ICalendarComponent = ((props: ICalendarComponent.IRenderProps) => ReactNode) | ReactNode;
export declare namespace ICalendarComponent {
    interface IRenderProps {
        classes: ICalendarStyles;
    }
}
export interface ICalendarShellEvents<TSourceSchema extends ISourceSchema<ICalendarEventSchema>> {
    schema: TSourceSchema["EntitySchema"];
    useSource: IUseSourceState<TSourceSchema>;
}
export interface ICalendarShellProps<TSourceSchema extends ISourceSchema<ICalendarEventSchema>> extends Omit<ComponentProps<typeof Container>, "children"> {
    events?: ICalendarShellEvents<TSourceSchema>;
    withControls?: boolean;
    controlsTopLeft?: ICalendarComponent;
    controlsTopMiddle?: ICalendarComponent;
    controlsTopRight?: ICalendarComponent;
    controlsBottomLeft?: ICalendarComponent;
    controlsBottomMiddle?: ICalendarComponent;
    controlsBottomRight?: ICalendarComponent;
    children: ICalendarComponent;
}
/**
 * Styled shell for Calendar.
 */
export declare const CalendarShell: <TSourceSchema extends ISourceSchema<import("zod").ZodObject<{
    id: import("zod").ZodString;
    date: import("zod").ZodEffects<import("zod").ZodString, import("luxon").DateTime, string>;
    prev: import("zod").ZodEffects<import("zod").ZodOptional<import("zod").ZodString>, import("luxon").DateTime | undefined, string | undefined>;
    next: import("zod").ZodEffects<import("zod").ZodOptional<import("zod").ZodString>, import("luxon").DateTime | undefined, string | undefined>;
}, "strip", import("zod").ZodTypeAny, {
    prev?: import("luxon").DateTime | undefined;
    next?: import("luxon").DateTime | undefined;
    date: import("luxon").DateTime;
    id: string;
}, {
    prev?: string | undefined;
    next?: string | undefined;
    date: string;
    id: string;
}>, import("@leight/source").ICreateSchema, import("zod").ZodObject<{
    id: import("zod").ZodString;
}, "strip", import("zod").ZodTypeAny, {
    id: string;
}, {
    id: string;
}>, import("@leight/filter").IFilterSchema, import("zod").ZodObject<{}, "strip", import("zod").ZodTypeAny, {}, {}>, import("zod").ZodObject<{}, "strip", import("zod").ZodTypeAny, {}, {}>> = ISourceSchema<import("zod").ZodObject<{
    id: import("zod").ZodString;
    date: import("zod").ZodEffects<import("zod").ZodString, import("luxon").DateTime, string>;
    prev: import("zod").ZodEffects<import("zod").ZodOptional<import("zod").ZodString>, import("luxon").DateTime | undefined, string | undefined>;
    next: import("zod").ZodEffects<import("zod").ZodOptional<import("zod").ZodString>, import("luxon").DateTime | undefined, string | undefined>;
}, "strip", import("zod").ZodTypeAny, {
    prev?: import("luxon").DateTime | undefined;
    next?: import("luxon").DateTime | undefined;
    date: import("luxon").DateTime;
    id: string;
}, {
    prev?: string | undefined;
    next?: string | undefined;
    date: string;
    id: string;
}>, import("@leight/source").ICreateSchema, import("zod").ZodObject<{
    id: import("zod").ZodString;
}, "strip", import("zod").ZodTypeAny, {
    id: string;
}, {
    id: string;
}>, import("@leight/filter").IFilterSchema, import("zod").ZodObject<{}, "strip", import("zod").ZodTypeAny, {}, {}>, import("zod").ZodObject<{}, "strip", import("zod").ZodTypeAny, {}, {}>>>({ events, withControls, controlsTopLeft, controlsTopMiddle, controlsTopRight, controlsBottomLeft, controlsBottomMiddle, controlsBottomRight, children, ...props }: ICalendarShellProps<TSourceSchema>) => JSX.Element;
export {};
//# sourceMappingURL=CalendarShell.d.ts.map